==> moodle-1.4.3-pgsql.tgz: moodle/lang/fi/forum.php <==
<?PHP // $Id$ 
      // forum.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004101900)


$string['addanewdiscussion'] = 'Lis uusi keskustelu';
$string['addanewtopic'] = 'Lis uusi aihe';
$string['allowchoice'] = 'Anna kaikkien valita';
$string['allowdiscussions'] = 'Voiko $a avata uusia keskusteluja?';
$string['allowratings'] = 'Voidaanko viestej arvioida?';
$string['allowsdiscussions'] = 'Tm keskustelualue antaa jokaisen aloittaa yhden uuden keskustelun.';
$string['anyfile'] = 'Mik tahansa tiedosto';
$string['attachment'] = 'Liite';
$string['bynameondate'] = '$a->name - $a->date';
$string['configdisplaymode'] = 'Oletusasetus keskustelujen nyttmiselle, jos sellaista ei ole asetettu.';
$string['configenablerssfeeds'] = 'Tm mahdollistaa RSS sytteet eri  keskustelualueilta. Sinun pit viel erikseen kytke RSS plle niiden keskustelualueiden asetuksesta jolla haluat kytt RSS sytteit.';
$string['configlongpost'] = 'Tt pitemmt keskustelut ovat pitki (HTML koodia ei lasketa mukaan).';
$string['configmanydiscussions'] = 'Samalla sivulla nytettvien keskustelujen suurin mr';
$string['configmaxbytes'] = 'Oletusasetus liitetiedoston maksimikoolle koko sivustolla.';
$string['configreplytouser'] = 'Kun foorumiposti on lhetetty, pitisik sen sislt kyttjien shkpostiosoite, jotta vastaanottajat voisivat vastata henkilkohtaisesti ennemmin kuin foorumin kautta? Vaikka asetukseksi valittaisiin kyll, kyttjt voivat valita profiilissaan pitvns shkpostiosoitteensa salaisena.';
$string['configshortpost'] = 'Tt lyhyemmt keskustelut ovat lyhyit (HTML koodia ei lasketa mukaan).';
$string['couldnotadd'] = 'Viestisi ei voida list tuntemattoman virheen takia.';
$string['couldnotdeleteratings'] = 'Valitettavasti viesti ei voida poistaa, koska se on jo arvioitu';
$string['couldnotdeletereplies'] = 'Valitettavasti viesti ei voida poistaa, koska siihen on jo vastattu';
$string['couldnotupdate'] = 'Viestisi ei voida pivitt tuntemattoman virheen takia';
$string['delete'] = 'Poista';
$string['deleteddiscussion'] = 'Keskustelu on poistettu';
$string['deletedpost'] = 'Viesti on poistettu';
$string['deletesure'] = 'Oletko varma, ett haluat poistaa tmn viestin?';
$string['digestmailheader'] = 'Tss on tmn pivn kertyt viestit keskustelualueilta $a->sitename. Vaihtaaksesi poistitus asetuksia, ky ositteessa $a->userprefs. ';
$string['digestmailprefs'] = 'asetuksesi';
$string['digestmailsubject'] = '$a: kertyt keskustelut';
$string['digestsentusers'] = 'Kertty email lhetetty $a kyttjlle';
$string['discussion'] = 'Keskustelu';
$string['discussionmoved'] = 'Tm keskustelu on siirretty paikkaan \'$a\'';
$string['discussionname'] = 'Keskustelun nimi';
$string['discussions'] = 'Keskustelut';
$string['discussionsstartedby'] = 'Keskustelun on aloittanut $a';
$string['discussionsstartedbyrecent'] = 'Viimeisimmn keskustelun aloittaja $a';
$string['discussthistopic'] = 'Keskustele aiheesta';
$string['eachuserforum'] = 'Jokainen avaa uuden keskustelun';
$string['edit'] = 'Muokkaa';
$string['editing'] = 'Muokataan';
$string['emptymessage'] = 'Jotain oli vialla viestisssi. Ehk jtit viestisi tyhjksi tai liitetiedosto oli liian suuri. Muutoksiasi EI tallennettu.';
$string['everyonecanchoose'] = 'Kaikki voivat tilata tmn keskustelualueen';
$string['everyoneissubscribed'] = 'Kaikki tilaavat tmn keskustelualueen';
$string['existingsubscribers'] = 'Nykyiset tilaajat';
$string['forcesubscribe'] = 'Pakota kaikki tilaajiksi';
$string['forcesubscribeq'] = 'Pakota kaikki tilaajiksi?';
$string['forum'] = 'Keskustelualue';
$string['forumintro'] = 'Keskustelualueen johdanto';
$string['forumname'] = 'Keskustelualueen nimi';
$string['forums'] = 'Keskustelualueet';
$string['forumtype'] = 'Keskustelualueen tyyppi';
$string['generalforum'] = 'Keskustelualue yleiseen kyttn';
$string['generalforums'] = 'Yleiset keskustelualueet';
$string['inforum'] = '$a :ssa';
$string['intronews'] = 'Yleiset uutiset ja tiedotteet';
$string['introsocial'] = 'Avoin keskustelualue vapaalle keskustelulle';
$string['introteacher'] = 'Opettajien oma keskustelualue';
$string['lastpost'] = 'Viimeisin viesti';
$string['learningforums'] = 'Keskustelualueet opiskelulle';
$string['maxattachmentsize'] = 'Liitteen maksimikoko';
$string['maxtimehaspassed'] = 'Valitettavasti suurin sallittu muokkausaika on ylittynyt tmn ($a) viestin osalta!';
$string['message'] = 'Viesti';
$string['modeflatnewestfirst'] = 'Nyt vastaukset perkkin, uusin ensin';
$string['modeflatoldestfirst'] = 'Nyt vastaukset perkkin, vanhin ensin';
$string['modenested'] = 'Nyt vastaukset siskkin';
$string['modethreaded'] = 'Nyt vastaukset sikeittin';
$string['modulename'] = 'Keskustelualue';
$string['modulenameplural'] = 'Keskustelualueet';
$string['more'] = 'lis';
$string['movethisdiscussionto'] = 'Siirr tm keskustelu ...';
$string['namenews'] = 'Uutiset';
$string['namesocial'] = 'Yleinen keskustelu';
$string['nameteacher'] = 'Opettajien keskustelualue';
$string['newforumposts'] = 'Keskustelualueen uudet viestit';
$string['nodiscussions'] = 'Tll keskustelualueella ei ole viel keskusteluja';
$string['noguestpost'] = 'Vieraat eivt saa kirjoittaa keskustelualueelle';
$string['nomorepostscontaining'] = 'Viestej, jotka sisltvt \'$a\' , ei lytynyt.';
$string['nonews'] = 'Ei viel uutisia';
$string['noposts'] = 'Ei viestej';
$string['nopostscontaining'] = 'Viestej jotka sisltvt \'$a\' ei lytynyt';
$string['nosubscribers'] = 'Tll keskustelualueella ei ole tilaajia';
$string['notingroup'] = 'Sinun pit olla ryhmn jsen nhdksesi tmn keskustelualueen.';
$string['nownotsubscribed'] = '$a->name EI saa kopioita viesteist\'$a->forum\' shkpostiinsa.';
$string['nowsubscribed'] = '$a->name SAA kopiot viesteist \'$a->forum\' shkpostiinsa.';
$string['numposts'] = '$a viesti';
$string['olderdiscussions'] = 'Vanhat keskustelut';
$string['openmode0'] = 'Ei keskusteja, ei vastauksia';
$string['openmode1'] = 'Ei keskusteluja, mutta vastaaminen sallitaan';
$string['openmode2'] = 'Keskustelut ja vastaukset sallitaan';
$string['parent'] = 'Nayt aiempi';
$string['parentofthispost'] = 'Tmn viestin alku';
$string['postadded'] = 'Viestisi on listty.<P>Sinulla $a aikaa muokata viesti jos haluat muuttaa sit.';
$string['postincontext'] = 'Katso tt viesti asiayhteydessn';
$string['postmailinfo'] = 'Tm on kopio viestist sivustolla $a.
Listksesi vastauksen viestiin suoraan sivustolle, klikkaa seuraavaa linkki:';
$string['postrating1'] = 'Suurimmaksi osaksi eristyv osaamista';
$string['postrating2'] = 'Yhtlaisesti eristynyt ja sosiaalinen';
$string['postrating3'] = 'Suurimmaksi osaksi sosiaalista osaamista';
$string['posts'] = 'Viestit';
$string['posttoforum'] = 'Lhet viesti';
$string['postupdated'] = 'Viestisi on pivitetty';
$string['potentialsubscribers'] = 'Mahdolliset tilaajat';
$string['processingdigest'] = 'Kertn viestej kyttjlle $a';
$string['processingpost'] = 'Ksitelln viesti $a';
$string['prune'] = 'Jaa';
$string['prunedpost'] = 'Uusi keskustelu on luotu tst viestist';
$string['pruneheading'] = 'Jaa keskustelu ja siirr tm viesti uuteen keskusteluun';
$string['rate'] = 'Arvio';
$string['rating'] = 'Arviointi';
$string['ratingeveryone'] = 'Kaikki voivat arvioida';
$string['ratingno'] = 'Ei arviointeja';
$string['ratingonlyteachers'] = 'Vain $a voi arvioida';
$string['ratingpublic'] = '$a voi nhd kaikkien arvioinnit';
$string['ratingpublicnot'] = '$a voi nhd vain omat arvioinnit';
$string['ratings'] = 'Arvioinnit';
$string['ratingssaved'] = 'Arviointi tallennettu';
$string['ratingsuse'] = 'Arviointitapa';
$string['ratingtime'] = 'Rajoita arviointi ajalle';
$string['re'] = 'Vast:';
$string['readtherest'] = 'Lue loput tst aiheesta';
$string['replies'] = 'Vastaukset';
$string['repliesmany'] = '$a vastausta thn menness';
$string['repliesone'] = '$a vastaus thn menness';
$string['reply'] = 'Vastaa';
$string['replyforum'] = 'Vastaa keskustelualueelle';
$string['rsssubscriberssdiscussions'] = 'Nyt RSS syte $a keskusteluille';
$string['rsssubscriberssposts'] = 'Nyt RSS syte $a viesteille';
$string['search'] = 'Etsi';
$string['searchforums'] = 'Etsi keskustelualueilta';
$string['searcholderposts'] = 'Selaa vanhoja viestej';
$string['searchresults'] = 'Haun tulokset';
$string['sendinratings'] = 'Lhet viimeisimmt arvioinnit viesteist';
$string['showsubscribers'] = 'Nyt/Muokaa tilaajia';
$string['singleforum'] = 'Yksinkertainen keskustelu';
$string['startedby'] = 'Aloittanut:';
$string['subject'] = 'Aihe';
$string['subscribe'] = 'Tilaa tm keskustelualue';
$string['subscribeall'] = 'Tilaa tm keskustelualue kaikille';
$string['subscribed'] = 'Tilaaja';
$string['subscribenone'] = 'Peru tmn keskustelualueen tilaukset kaikilta';
$string['subscribers'] = 'Tilaajat';
$string['subscribersto'] = 'Tilaa \'$a\'';
$string['subscribestart'] = 'Lhet kopiot viesteist tlle keskustelualueelle shkpostiini';
$string['subscribestop'] = 'En halua kopioita viesteist tlle keskustelualueelle';
$string['subscription'] = 'Tilaus';
$string['subscriptions'] = 'Tilaukset';
$string['thischarset'] = 'iso-8859-1';
$string['thisdirection'] = 'ltr';
$string['thislanguage'] = 'Suomi';
$string['unsubscribe'] = 'Peru tmn keskustelualueen tilaus';
$string['unsubscribed'] = 'Tilaamaton';
$string['unsubscribeshort'] = 'Peru tilaus';
$string['yesforever'] = 'Kyll, aluksi';
$string['yesinitially'] = 'Kyll, pysyvsti';
$string['youratedthis'] = 'Arvioit tmn';
$string['yournewtopic'] = 'Uusi keskustelun aihe';
$string['yourreply'] = 'Vastauksesi';

?>

==> moodle-1.5-pgsql.tgz: moodle/lang/fi/forum.php <==
<?PHP // $Id$ 
      // forum.php - created with Moodle 1.5 + (2005060201)


$string['addanewdiscussion'] = 'Lis uusi keskustelu';
$string['addanewtopic'] = 'Lis uusi aihe';
$string['advancedsearch'] = 'Tarkennettu haku';
$string['allforums'] = 'Kaikki keskustelualueet';
$string['allowchoice'] = 'Anna kaikkien valita';
$string['allowdiscussions'] = 'Voiko $a avata uusia keskusteluja?';
$string['allowratings'] = 'Voidaanko viestej arvioida?';
$string['allowsdiscussions'] = 'Tm keskustelualue antaa jokaisen aloittaa yhden uuden keskustelun.';
$string['anyfile'] = 'Mik tahansa tiedosto';
$string['attachment'] = 'Liite';
$string['bynameondate'] = '$a->name - $a->date';
$string['configdisplaymode'] = 'Oletusasetus keskustelujen nyttmiselle, jos sellaista ei ole asetettu.';
$string['configenablerssfeeds'] = 'Tm mahdollistaa RSS-sytteet eri keskustelualueilta. Sinun pit viel erikseen kytke RSS plle niiden keskustelualueiden asetuksesta, joille haluat kytt RSS-sytteit.';
$string['configlongpost'] = 'Tt pitemmt keskustelut ksitelln pitkin (HTML koodia ei lasketa mukaan).';
$string['configmanydiscussions'] = 'Samalla sivulla nytettvien keskustelujen suurin mr';
$string['configmaxbytes'] = 'Oletusasetus liitetiedoston maksimikoolle koko sivustolla.';
$string['configreplytouser'] = 'Kun foorumiposti on lhetetty, pitisik sen sislt kyttjien shkpostiosoite, jotta vastaanottajat voisivat vastata henkilkohtaisesti ennemmin kuin foorumin kautta? Vaikka asetukseksi valittaisiin kyll, kyttjt voivat valita profiilissaan pitvns shkpostiosoitteensa salaisena.';
$string['configshortpost'] = 'Tt lyhyemmt keskustelut ovat lyhyit (HTML koodia ei lasketa mukaan).';
$string['couldnotadd'] = 'Viestisi ei voida list tuntemattoman virheen takia.';
$string['couldnotdeleteratings'] = 'Valitettavasti viesti ei voida poistaa, koska se on jo arvioitu';
$string['couldnotdeletereplies'] = 'Valitettavasti viesti ei voida poistaa, koska siihen on jo vastattu';
$string['couldnotupdate'] = 'Viestisi ei voida pivitt tuntemattoman virheen takia';
$string['delete'] = 'Poista';
$string['deleteddiscussion'] = 'Keskustelu on poistettu';
$string['deletedpost'] = 'Viesti on poistettu';
$string['deletedposts'] = 'Viestit on poistettu';
$string['deletesure'] = 'Oletko varma, ett haluat poistaa tmn viestin?';
$string['digestmailheader'] = 'Tss on tmn pivn kertyt viestit keskustelualueilta $a->sitename. Vaihtaaksesi poistitus asetuksia, ky ositteessa $a->userprefs. ';
$string['digestmailprefs'] = 'asetuksesi';
$string['digestmailsubject'] = '$a: kertyt keskustelut';
$string['digestsentusers'] = 'Kertty email lhetetty $a kyttjlle';
$string['discussion'] = 'Keskustelu';
$string['discussionmoved'] = 'Tm keskustelu on siirretty paikkaan \'$a\'';
$string['discussionname'] = 'Keskustelun nimi';
$string['discussions'] = 'Keskustelut';
$string['discussionsstartedby'] = 'Keskustelun on aloittanut $a';
$string['discussionsstartedbyrecent'] = 'Viimeisimmn keskustelun aloittaja $a';
$string['discussthistopic'] = 'Keskustele aiheesta';
$string['eachuserforum'] = 'Jokainen avaa uuden keskustelun';
$string['edit'] = 'Muokkaa';
$string['editedby'] = 'Muokattu $a->name:n toimesta $->date';
$string['editing'] = 'Muokataan';
$string['emptymessage'] = 'Jotain oli vialla viestisssi. Ehk jtit viestisi tyhjksi tai liitetiedosto oli liian suuri. Muutoksiasi EI tallennettu.';
$string['everyonecanchoose'] = 'Kaikki voivat tilata tmn keskustelualueen';
$string['everyoneissubscribed'] = 'Kaikki tilaavat tmn keskustelualueen';
$string['existingsubscribers'] = 'Nykyiset tilaajat';
$string['forcesubscribe'] = 'Pakota kaikki tilaajiksi';
$string['forcesubscribeq'] = 'Pakota kaikki tilaajiksi?';
$string['forum'] = 'Keskustelualue';
$string['forumintro'] = 'Keskustelualueen johdanto';
$string['forumname'] = 'Keskustelualueen nimi';
$string['forumposts'] = 'Keskustelualueen viestit';
$string['forums'] = 'Keskustelualueet';
$string['forumtype'] = 'Keskustelualueen tyyppi';
$string['generalforum'] = 'Keskustelualue yleiseen kyttn';
$string['generalforums'] = 'Yleiset keskustelualueet';
$string['inforum'] = '$a :ssa';
$string['intronews'] = 'Yleiset uutiset ja tiedotteet';
$string['introsocial'] = 'Avoin keskustelualue vapaalle keskustelulle';
$string['introteacher'] = 'Opettajien oma keskustelualue';
$string['lastpost'] = 'Viimeisin viesti';
$string['learningforums'] = 'Keskustelualueet opiskelulle';
$string['markalldread'] = 'Merkite kaikki keskustelun viestit luetuiksi';
$string['markallread'] = 'Merkite kaikki alueen viestit luetuiksi';
$string['markread'] = 'Merkitse luetuksi';
$string['markreadbutton'] = 'Merkitse <br />luetuksi';
$string['markunread'] = 'Merkitse lukemattomaksi';
$string['markunreadbutton'] = 'Merkitse <br />lukemattomaksi';
$string['maxattachmentsize'] = 'Liitteen maksimikoko';
$string['maxtimehaspassed'] = 'Valitettavasti suurin sallittu muokkausaika on ylittynyt tmn ($a) viestin osalta!';
$string['message'] = 'Viesti';
$string['modeflatnewestfirst'] = 'Nyt vastaukset perkkin, uusin ensin';
$string['modeflatoldestfirst'] = 'Nyt vastaukset perkkin, vanhin ensin';
$string['modenested'] = 'Nyt vastaukset siskkin';
$string['modethreaded'] = 'Nyt vastaukset sikeittin';
$string['modulename'] = 'Keskustelualue';
$string['modulenameplural'] = 'Keskustelualueet';
$string['more'] = 'lis';
$string['movethisdiscussionto'] = 'Siirr tm keskustelu ...';
$string['namenews'] = 'Uutiset';
$string['namesocial'] = 'Yleinen keskustelu';
$string['nameteacher'] = 'Opettajien keskustelualue';
$string['newforumposts'] = 'Keskustelualueen uudet viestit';
$string['nodiscussions'] = 'Tll keskustelualueella ei ole viel keskusteluja';
$string['noguestpost'] = 'Vieraat eivt saa kirjoittaa keskustelualueelle';
$string['nomorepostscontaining'] = 'Viestej, jotka sisltvt \'$a\' , ei lytynyt.';
$string['nonews'] = 'Ei viel uutisia';
$string['noposts'] = 'Ei viestej';
$string['nopostscontaining'] = 'Viestej jotka sisltvt \'$a\' ei lytynyt';
$string['nosubscribers'] = 'Tll keskustelualueella ei ole tilaajia';
$string['notingroup'] = 'Sinun pit olla ryhmn jsen nhdksesi tmn keskustelualueen.';
$string['nownotsubscribed'] = '$a->name EI saa kopioita viesteist\'$a->forum\' shkpostiinsa.';
$string['nowsubscribed'] = '$a->name SAA kopiot viesteist \'$a->forum\' shkpostiinsa.';
$string['numposts'] = '$a viesti';
$string['olderdiscussions'] = 'Vanhat keskustelut';
$string['openmode0'] = 'Ei keskusteja, ei vastauksia';
$string['openmode1'] = 'Ei keskusteluja, mutta vastaaminen sallitaan';
$string['openmode2'] = 'Keskustelut ja vastaukset sallitaan';
$string['parent'] = 'Nayt aiempi';
$string['parentofthispost'] = 'Tmn viestin alku';
$string['postadded'] = '<p>Viestisi on listty.</p><p>Sinulla $a aikaa muokata viesti jos haluat muuttaa sit.</p>';
$string['postincontext'] = 'Katso tt viesti asiayhteydessn';
$string['postmailinfo'] = 'Tm on kopio viestist sivustolla $a.
Listksesi vastauksen viestiin suoraan sivustolle, klikkaa seuraavaa linkki:';
$string['postrating1'] = 'Suurimmaksi osaksi eristyv osaamista';
$string['postrating2'] = 'Yhtlaisesti eristynyt ja sosiaalinen';
$string['postrating3'] = 'Suurimmaksi osaksi sosiaalista osaamista';
$string['posts'] = 'Viestit';
$string['posttoforum'] = 'Lhet viesti';
$string['postupdated'] = 'Viestisi on pivitetty';
$string['potentialsubscribers'] = 'Mahdolliset tilaajat';
$string['processingdigest'] = 'Kertn viestej kyttjlle $a';
$string['processingpost'] = 'Ksitelln viesti $a';
$string['prune'] = 'Jaa';
$string['prunedpost'] = 'Uusi keskustelu on luotu tst viestist';
$string['pruneheading'] = 'Jaa keskustelu ja siirr tm viesti uuteen keskusteluun';
$string['rate'] = 'Arvio';
$string['rating'] = 'Arviointi';
$string['ratingeveryone'] = 'Kaikki voivat arvioida';
$string['ratingno'] = 'Ei arviointeja';
$string['ratingonlyteachers'] = 'Vain $a voi arvioida';
$string['ratingpublic'] = '$a voi nhd kaikkien arvioinnit';
$string['ratingpublicnot'] = '$a voi nhd vain omat arvioinnit';
$string['ratings'] = 'Arvioinnit';
$string['ratingssaved'] = 'Arviointi tallennettu';
$string['ratingsuse'] = 'Arviointitapa';
$string['ratingtime'] = 'Rajoita arviointi ajalle';
$string['re'] = 'Vast:';
$string['readtherest'] = 'Lue loput tst aiheesta';
$string['replies'] = 'Vastaukset';
$string['repliesmany'] = '$a vastausta thn menness';
$string['repliesone'] = '$a vastaus thn menness';
$string['reply'] = 'Vastaa';
$string['replyforum'] = 'Vastaa keskustelualueelle';
$string['rsssubscriberssdiscussions'] = 'Nyt alueen \"$a\" keskusteluiden RSS-syte';
$string['rsssubscriberssposts'] = 'Nyt alueen \"$a\" viestien RSS-syte';
$string['search'] = 'Etsi';
$string['searchdatefrom'] = 'Viestin tulee olla uudempi kuin';
$string['searchdateto'] = 'Viestin tulee olla vanhempi kuin';
$string['searchforumintro'] = 'Tyt hakuehto yhteen tai tai usempaan kenttn:';
$string['searchforums'] = 'Etsi viesteist';
$string['searchfullwords'] = 'Nm sanat tulee olla kokonaisina';
$string['searchnotwords'] = 'l huomioi nit sanoja';
$string['searcholderposts'] = 'Selaa vanhoja viestej';
$string['searchphrase'] = 'Tm fraasi tulee olla viestiss';
$string['searchresults'] = 'Haun tulokset';
$string['searchsubject'] = 'Nit sanoja viestin aiheessa';
$string['searchuser'] = 'Viestin kirjoittajan nimi  tulisi olla';
$string['searchuserid'] = 'Viestin kirjoittajan tunnus tulisi olla';
$string['searchwhichforums'] = 'Valitse haettavat alueet';
$string['searchwords'] = 'Nit sanoja viestin sisllst';
$string['seeallposts'] = 'Kaikki tmn kyttjn viestit';
$string['sendinratings'] = 'Lhet viimeisimmt arvioinnit viesteist';
$string['showsubscribers'] = 'Nyt/Muokaa tilaajia';
$string['singleforum'] = 'Yksinkertainen keskustelu';
$string['startedby'] = 'Aloittanut:';
$string['subject'] = 'Aihe';
$string['subscribe'] = 'Tilaa tm keskustelualue';
$string['subscribeall'] = 'Tilaa tm keskustelualue kaikille';
$string['subscribed'] = 'Tilaaja';
$string['subscribenone'] = 'Peru tmn keskustelualueen tilaukset kaikilta';
$string['subscribers'] = 'Tilaajat';
$string['subscribersto'] = 'Tilaa \'$a\'';
$string['subscribestart'] = 'Lhet kopiot viesteist tlle keskustelualueelle shkpostiini';
$string['subscribestop'] = 'En halua kopioita viesteist tlle keskustelualueelle';
$string['subscription'] = 'Tilaus';
$string['subscriptions'] = 'Tilaukset';
$string['trackforum'] = 'Seuraa lukamatta olevia viestej';
$string['tracking'] = 'Seuraa';
$string['trackingoff'] = 'Pois';
$string['trackingon'] = 'Pll';
$string['trackingoptional'] = 'Valinnainen';
$string['trackingtype'] = 'Seuraa tmn alueen lukemista';
$string['unread'] = 'Lukematta';
$string['unreadposts'] = 'Lukemattomat viestit';
$string['unreadpostsnumber'] = '$a lukematonta viesti';
$string['unreadpostsone'] = '$a lukematon viesti';
$string['unsubscribe'] = 'Peru tmn keskustelualueen tilaus';
$string['unsubscribed'] = 'Tilaamaton';
$string['unsubscribeshort'] = 'Peru tilaus';
$string['yesforever'] = 'Kyll, pysyvsti';
$string['yesinitially'] = 'Kyll, aluksi';
$string['youratedthis'] = 'Arvioit tmn';
$string['yournewtopic'] = 'Uusi keskustelun aihe';
$string['yourreply'] = 'Vastauksesi';

?>
